﻿using Infragistics.Win;
using Infragistics.Win.UltraWinEditors;
using Infragistics.Win.UltraWinGrid;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace UltraWinGrid
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();

            this.ultraGrid1.DataSource = GetEmployees();

            UltraGridColumn columnEmissivity = ultraGrid1.DisplayLayout.Bands[0].Columns["Department"];
            columnEmissivity.Style = Infragistics.Win.UltraWinGrid.ColumnStyle.DoublePositiveWithSpin;
            columnEmissivity.MaskInput = "-nn.nn";

        }
        private DataSet GetEmployDepartmentDataSet()
        {
            DataSet ds = new DataSet("EmployeeRecords");

            // Get the tables to use in the DataSet
            DataTable Employees = this.GetEmployees();
            DataTable Departments = this.GetDepartments();
            DataTable Options = this.GetEmployeeOptions();

            // Add the tables to the DataSet
            ds.Tables.Add(Departments);
            ds.Tables.Add(Employees);
            ds.Tables.Add(Options);

            // Create the relationship between the tables.
            ds.Relations.Add("DepartmentEmployee", Departments.Columns["DepartmentID"], Employees.Columns["Department"]);
            ds.Relations.Add("EmployeeOption", Employees.Columns["EmployeeID"], Options.Columns["Employee"]);
            return ds;
        }
        private DataTable GetDepartments()
        {
            DataTable dt = new DataTable("Departments");
            dt.Columns.Add("DepartmentID", typeof(int));
            dt.Columns.Add("DepartmentName", typeof(string));
            dt.Columns.Add("Number", typeof(int));

            for (int i = 0; i < 8; i++)
            {
                dt.Rows.Add(new object[] {i, string.Format("Department {0}", i), i});
            }

            dt.PrimaryKey = new DataColumn[] { dt.Columns["DepartmentID"] };

            return dt;
        }

        private DataTable GetEmployees()
        {
            DataTable dtData = new DataTable("Employees");

            dtData.Columns.Add("EmployeeID", typeof(int));
            dtData.Columns.Add("Name", typeof(string));
            dtData.Columns.Add("OnSite", typeof(bool));
            dtData.Columns.Add("DateOfHire", typeof(DateTime));
            dtData.Columns.Add("Department", typeof(double));


            for (int i = 0; i < 250; i++)
            {
                dtData.Rows.Add(new object[] { i, string.Format("Name {0}", i), (i % 2 == 0), DateTime.Today.Date.AddDays(-1 * i), i % 8 });
            }

            dtData.PrimaryKey = new DataColumn[] { dtData.Columns["EmployeeID"] };

            return dtData;
        }

        private DataTable GetEmployeeOptions()
        {
            DataTable dtData = new DataTable("EmployeeOptions");

            dtData.Columns.Add("OptionID", typeof(int));
            dtData.Columns.Add("Employee", typeof(int));
            dtData.Columns.Add("Option", typeof(string));
            dtData.Columns.Add("Description", typeof(string));


            for (int i = 0; i < 96; i++)
            {
                dtData.Rows.Add(new object[] { i, i % 24, string.Format("Option {0}", i), String.Format("Option Description {0}", i) });
            }

            dtData.PrimaryKey = new DataColumn[] { dtData.Columns["OptionID"] };

            return dtData;
        }

        private void button1_Click(object sender, EventArgs e)
        {

        }

        private void ultraGrid1_InitializeLayout(object sender, InitializeLayoutEventArgs e)
        {

            //this.ultraGrid1.DisplayLayout.Bands[0].Columns[2].EditorComponent = new UltraCombo();
            //((Infragistics.Win.UltraWinGrid.UltraCombo)((Infragistics.Win.UltraWinGrid.UltraGridColumn)((Infragistics.Shared.IKeyedSubObject[])this.ultraGrid1.DisplayLayout.Bands[0].Columns.All)[3]).EditorComponent).DropDownStyle = UltraComboStyle.DropDown;
        }

        private void ultraGrid1_InitializeRow(object sender, InitializeRowEventArgs e)
        {

        }

        private void ultraGrid1_BeforeRowsDeleted(object sender, BeforeRowsDeletedEventArgs e)
        {
            this.ultraGrid1.ActiveRow = e.Rows[0].ParentRow;
        }

        private void ultraGrid1_DoubleClick(object sender, EventArgs e)
        {

        }
    }
}
